@@ -18,6 +18,7 @@ package org.jclouds.elb.domain;
 
 import static com.google.common.base.Preconditions.checkNotNull;
 
+import com.google.common.base.MoreObjects;
 import com.google.common.base.Objects;
 import com.google.common.base.Optional;
 
@@ -157,7 +158,7 @@ public class InstanceHealth {
     */
    @Override
    public String toString() {
-      return Objects.toStringHelper(this).omitNullValues().add("description", description)
+      return MoreObjects.toStringHelper(this).omitNullValues().add("description", description)
                .add("instanceId", instanceId).add("reasonCode", reasonCode.orNull()).add("state", state).toString();
    }
 
