@@ -103,7 +103,7 @@ public class DescribeInstanceHealthResultHandler extends
     * {@inheritDoc}
     */
    @Override
-   public void characters(char ch[], int start, int length) {
+   public void characters(char[] ch, int start, int length) {
       if (inStates) {
          instanceStateHandler.characters(ch, start, length);
       } else {
