@@ -94,7 +94,7 @@ public class InstanceProfileHandler extends ParseSax.HandlerForGeneratedRequestW
    }
 
    @Override
-   public void characters(char ch[], int start, int length) {
+   public void characters(char[] ch, int start, int length) {
       if (inRoles) {
          roleHandler.characters(ch, start, length);
       } else {
