@@ -57,7 +57,7 @@ public class PolicyHandler extends ParseSax.HandlerForGeneratedRequestWithResult
    }
 
    @Override
-   public void characters(char ch[], int start, int length) {
+   public void characters(char[] ch, int start, int length) {
       currentText.append(ch, start, length);
    }
 }
